@@ -105,7 +105,7 @@ typedef enum {
 
 /*To satisfy h2defs.py */
 #define GTKOSX_TYPE_APPLICATION_ATTENTION_TYPE	(gtkosx_type_application_attention_type_get_type())
-// GType gtkosx_type_application_attention_type_get_type(void);
+GType gtkosx_type_application_attention_type_get_type(void);
 
 void gtkosx_application_set_dock_menu(GtkosxApplication *self, 
 				   GtkMenuShell *menu_shell);
